@@ -19,8 +19,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef gama_local_acord___ReduceToElipsoid__header___h
-#define gama_local_acord___ReduceToElipsoid__header___h
+#ifndef gama_local_acord_ReduceToElipsoid_header_h
+#define gama_local_acord_ReduceToElipsoid_header_h
 
 #include <gnu_gama/ellipsoid.h>
 
