@@ -53,7 +53,7 @@ bool GeneralParameters(GNU_gama::local::LocalNetwork* IS, OutStream& out)
   using namespace std;
   using namespace GNU_gama::local;
 
-  IS->null_space();   // triggers adjusment; needed for printing removed points
+  IS->null_space();   // triggers adjustment; needed for printing removed points
 
   {
     if (!IS->removed_points.empty())
@@ -423,7 +423,7 @@ bool GeneralParameters(GNU_gama::local::LocalNetwork* IS, OutStream& out)
           out << '\n';
         }
 
-      Observation* ptr {nullptr};
+      Observation* obs {nullptr};
       double stud_opr;
       double max_stud = 0;
       int imax = 0;
@@ -436,7 +436,7 @@ bool GeneralParameters(GNU_gama::local::LocalNetwork* IS, OutStream& out)
               if (stud_opr > max_stud)
                 {
                   max_stud = stud_opr;
-                  ptr = IS->ptr_obs(i);
+                  obs = IS->ptr_obs(i);
                   imax = i;
                 }
             }
@@ -479,8 +479,8 @@ bool GeneralParameters(GNU_gama::local::LocalNetwork* IS, OutStream& out)
               << setprecision(0) << (1 - IS->conf_pr())*100
               << T_GaMa_genpar_for_observation_ind
               << imax << "\n";
-          WriteVisitor<OutStream> write_visitor(out, true);
-          ptr->accept(&write_visitor);
+          WriteVisitor<OutStream> write_visitor(out, true, IS->y_sign());
+          obs->accept(&write_visitor);
           out << "\n";
         }
 
